/**
 * First-in, first-out (FIFO) buffer (queue) with default item values.
 * Optionally circular based on {@link Buffer.limit}.
 */
export default class Buffer<A> {
    #private;
    /** The length after which the queue becomes circular, i.e., discards oldest items. */
    readonly limit: number;
    length: number;
    constructor(
    /** The length after which the queue becomes circular, i.e., discards oldest items. */
    limit?: number);
    /**
     * Add an item to the end of the queue.
     */
    enqueue(value: A): void;
    /**
     * Return the oldest item from the queue.
     */
    dequeue(): A;
    clear(): void;
    forEach(f: (value: A) => void): void;
    [Symbol.iterator](): {
        next: () => {
            value: A;
            done: boolean;
        } | {
            done: boolean;
            value?: undefined;
        };
        [Symbol.iterator](): any;
    };
    static from<A>(iterable: Iterable<A>, limit: number): Buffer<A>;
}
